# 邮箱必要参数
HOST = ''
PORT = 994
USER = ''
PASSWORD = ''
RECEIVERS = []
WARNING_USER = []
SUBJECT = ''
CONTENT = ''

# 邮箱可选参数
# 附件名
ATTACHES = []
SHEET_NAMES = []
# 抄件人
# CARBON_COPY = []
# MASK
# SENDER_MASK = ''
# RECEIVERS_MASK = []
# CARBON_COPY_MASK = []